@@ -181,6 +181,9 @@ static unsigned get_type( unsigned uiProperty )
     case LIBMSI_PROPERTY_SECURITY:
     case LIBMSI_PROPERTY_VERSION:
          return OLEVT_I4;
+
+    default:
+        g_warn_if_reached ();
     }
     return OLEVT_EMPTY;
 }
@@ -316,19 +319,19 @@ static void read_properties_from_data( LibmsiOLEVariant *prop, const uint8_t *da
     for( i = 0; i < cProperties; i++ )
     {
         int propid = read_dword(data, &idofs);
-        int dwOffset = read_dword(data, &idofs);
+        unsigned dwOffset = read_dword(data, &idofs);
         int proptype;
 
         if( propid >= MSI_MAX_PROPS )
         {
-            ERR("Unknown property ID %d\n", propid );
+            g_critical("Unknown property ID %d\n", propid );
             break;
         }
 
         type = get_type( propid );
         if( type == OLEVT_EMPTY )
         {
-            ERR("propid %d has unknown type\n", propid);
+            g_critical("propid %d has unknown type\n", propid);
             break;
         }
 
@@ -336,14 +339,14 @@ static void read_properties_from_data( LibmsiOLEVariant *prop, const uint8_t *da
 
         if( dwOffset + 4 > sz )
         {
-            ERR("not enough data for type %d %d \n", dwOffset, sz);
+            g_critical("not enough data for type %d %d \n", dwOffset, sz);
             break;
         }
 
         proptype = read_dword(data, &dwOffset);
         if( dwOffset + 4 > sz )
         {
-            ERR("not enough data for type %d %d \n", dwOffset, sz);
+            g_critical("not enough data for type %d %d \n", dwOffset, sz);
             break;
         }
 
@@ -357,7 +360,7 @@ static void read_properties_from_data( LibmsiOLEVariant *prop, const uint8_t *da
         case OLEVT_FILETIME:
             if( dwOffset + 8 > sz )
             {
-                ERR("not enough data for type %d %d \n", dwOffset, sz);
+                g_critical("not enough data for type %d %d \n", dwOffset, sz);
                 break;
             }
             property->filetime = read_dword(data, &dwOffset);
@@ -367,13 +370,15 @@ static void read_properties_from_data( LibmsiOLEVariant *prop, const uint8_t *da
             len = read_dword(data, &dwOffset);
             if( dwOffset + len > sz )
             {
-                ERR("not enough data for type %d %d %d \n", dwOffset, len, sz);
+                g_critical("not enough data for type %d %d %d \n", dwOffset, len, sz);
                 break;
             }
             str = msi_alloc( len );
             memcpy( str, &data[dwOffset], len-1 );
             str[ len - 1 ] = 0;
             break;
+        default:
+            g_warn_if_reached ();
         }
 
         /* check the type is the same as we expect */
@@ -391,7 +396,7 @@ static void read_properties_from_data( LibmsiOLEVariant *prop, const uint8_t *da
         }
         else
         {
-            ERR("invalid type \n");
+            g_critical("invalid type \n");
             break;
         }
     }
@@ -421,7 +426,7 @@ static unsigned load_summary_info( LibmsiSummaryInfo *si, GsfInput *stm )
     ofs = 0;
     if( read_word( data, &ofs) != 0xfffe )
     {
-        ERR("property set not little-endian\n");
+        g_critical("property set not little-endian\n");
         goto done;
     }
 
@@ -442,7 +447,7 @@ static unsigned load_summary_info( LibmsiSummaryInfo *si, GsfInput *stm )
 
     if( cProperties > MSI_MAX_PROPS )
     {
-        ERR("too many properties %d\n", cProperties);
+        g_critical("too many properties %d\n", cProperties);
         goto done;
     }
 
@@ -516,6 +521,8 @@ static unsigned write_property_to_data( const LibmsiOLEVariant *prop, uint8_t *d
     case OLEVT_LPSTR:
         sz += write_string( data, sz, prop->strval );
         break;
+    default:
+        g_warn_if_reached ();
     }
     return sz;
 }
@@ -680,7 +687,8 @@ static void _summary_info_get_property (LibmsiSummaryInfo *si, unsigned uiProper
             if (szValueBuf)
                 strcpyn (szValueBuf, prop->strval, *pcchValueBuf);
             if (len >= *pcchValueBuf)
-                g_set_error (error, LIBMSI_RESULT_ERROR, LIBMSI_RESULT_MORE_DATA, "");
+                g_set_error (error, LIBMSI_RESULT_ERROR, LIBMSI_RESULT_MORE_DATA,
+                             "The given string is too small");
             *pcchValueBuf = len;
         }
         break;
@@ -695,8 +703,7 @@ static void _summary_info_get_property (LibmsiSummaryInfo *si, unsigned uiProper
         type = LIBMSI_PROPERTY_TYPE_EMPTY;
         break;
     default:
-        g_warn_if_reached ();
-        break;
+        g_return_if_reached ();
     }
 
     if (puiDataType)
@@ -827,6 +834,8 @@ static LibmsiResult _libmsi_summary_info_set_property( LibmsiSummaryInfo *si, un
         prop->strval = msi_alloc( len );
         strcpy( prop->strval, szValue );
         break;
+    default:
+        g_warn_if_reached ();
     }
 
     ret = LIBMSI_RESULT_SUCCESS;
@@ -974,7 +983,7 @@ static unsigned parse_prop( const char *prop, const char *value, unsigned *pid,
         break;
 
     default:
-        WARN("unhandled prop id %u\n", *pid);
+        g_warning("unhandled prop id %u\n", *pid);
         return LIBMSI_RESULT_FUNCTION_FAILED;
     }
 
@@ -990,7 +999,7 @@ unsigned msi_add_suminfo( LibmsiDatabase *db, char ***records, int num_records,
     si = libmsi_summary_info_new (db, num_records * (num_columns / 2), NULL);
     if (!si)
     {
-        ERR("no summary information!\n");
+        g_critical("no summary information!\n");
         return LIBMSI_RESULT_FUNCTION_FAILED;
     }
 
