@@ -96,7 +96,7 @@ static inline unsigned bytes_per_column( LibmsiDatabase *db, const LibmsiColumnI
         return 2;
 
     if( (col->type & 0xff) != 4 )
-        ERR("Invalid column size!\n");
+        g_critical("Invalid column size!\n");
 
     return 4;
 }
@@ -170,7 +170,7 @@ char *encode_streamname(bool bTable, const char *in)
             *p++ = ch;
         }
     }
-    ERR("Failed to encode stream name (%s)\n",debugstr_a(in));
+    g_critical("Failed to encode stream name (%s)\n",debugstr_a(in));
     msi_free( out );
     return NULL;
 }
@@ -263,13 +263,13 @@ unsigned read_stream_data( GsfInfile *stg, const char *stname,
     msi_free(encname);
     if( !stm )
     {
-        WARN("open stream failed - empty table?\n");
+        TRACE("open stream failed - empty table?\n");
         return ret;
     }
 
     if( gsf_input_size(stm) >> 32 )
     {
-        WARN("Too big!\n");
+        g_warning("Too big!\n");
         goto end;
     }
         
@@ -283,7 +283,7 @@ unsigned read_stream_data( GsfInfile *stg, const char *stname,
         data = g_try_malloc( sz );
         if( !data )
         {
-            WARN("couldn't allocate memory (%u bytes)!\n", sz);
+            g_warning("couldn't allocate memory (%u bytes)!\n", sz);
             ret = LIBMSI_RESULT_NOT_ENOUGH_MEMORY;
             goto end;
         }
@@ -291,7 +291,7 @@ unsigned read_stream_data( GsfInfile *stg, const char *stname,
         if (! gsf_input_read( stm, sz, data ))
         {
             msi_free( data );
-            WARN("read stream failed\n");
+            g_warning("read stream failed\n");
             goto end;
         }
     }
@@ -322,13 +322,13 @@ unsigned write_stream_data( LibmsiDatabase *db, const char *stname,
     msi_free( encname );
     if( !stm )
     {
-        WARN("open stream failed\n");
+        g_warning("open stream failed\n");
         return ret;
     }
 
     if (! gsf_output_write(stm, sz, data) )
     {
-        WARN("Failed to Write\n");
+        g_warning("Failed to Write\n");
         goto end;
     }
 
@@ -395,7 +395,7 @@ static unsigned read_table_from_storage( LibmsiDatabase *db, LibmsiTable *t, Gsf
 
     if( rawsize % row_size )
     {
-        WARN("Table size is invalid %d/%d\n", rawsize, row_size );
+        g_warning("Table size is invalid %d/%d\n", rawsize, row_size );
         goto err;
     }
 
@@ -426,7 +426,7 @@ static unsigned read_table_from_storage( LibmsiDatabase *db, LibmsiTable *t, Gsf
 
             if ( n != 2 && n != 3 && n != 4 )
             {
-                ERR("oops - unknown column width %d\n", n);
+                g_critical("oops - unknown column width %d\n", n);
                 goto err;
             }
             if (t->colinfo[j].type & MSITYPE_STRING && n < m)
@@ -467,6 +467,7 @@ void free_cached_tables( LibmsiDatabase *db )
     }
 }
 
+G_GNUC_PURE
 static LibmsiTable *find_cached_table( LibmsiDatabase *db, const char *name )
 {
     LibmsiTable *t;
@@ -563,10 +564,11 @@ unsigned _libmsi_open_table( LibmsiDatabase *db, const char *name, bool encoded
 {
     char decname[0x40];
     LibmsiTable *table;
+    guint8 *name8 = (guint8*)name;
 
     if (encoded)
     {
-        assert(name[0] == 0xe4 && name[1] == 0xa1 && name[2] == 0x80);
+        assert(name8[0] == 0xe4 && name8[1] == 0xa1 && name8[2] == 0x80);
         decode_streamname( name + 1, decname );
         name = decname;
     }
@@ -651,7 +653,7 @@ static unsigned get_tablecolumns( LibmsiDatabase *db, const char *szTableName, L
     r = get_table( db, szColumns, &table );
     if (r != LIBMSI_RESULT_SUCCESS)
     {
-        ERR("couldn't load _Columns table\n");
+        g_critical("couldn't load _Columns table\n");
         return LIBMSI_RESULT_FUNCTION_FAILED;
     }
 
@@ -659,7 +661,7 @@ static unsigned get_tablecolumns( LibmsiDatabase *db, const char *szTableName, L
     r = _libmsi_id_from_string_utf8( db->strings, szTableName, &table_id );
     if (r != LIBMSI_RESULT_SUCCESS)
     {
-        WARN("Couldn't find id for %s\n", debugstr_a(szTableName));
+        g_warning("Couldn't find id for %s\n", debugstr_a(szTableName));
         return r;
     }
     TRACE("Table id is %d, row count is %d\n", table_id, table->row_count);
@@ -680,13 +682,13 @@ static unsigned get_tablecolumns( LibmsiDatabase *db, const char *szTableName, L
             /* check the column number is in range */
             if (col < 1 || col > maxcount)
             {
-                ERR("column %d out of range\n", col);
+                g_critical("column %d out of range\n", col);
                 continue;
             }
             /* check if this column was already set */
             if (colinfo[col - 1].number)
             {
-                ERR("duplicate column %d\n", col);
+                g_critical("duplicate column %d\n", col);
                 continue;
             }
             colinfo[col - 1].tablename = msi_string_lookup_id( db->strings, table_id );
@@ -704,7 +706,7 @@ static unsigned get_tablecolumns( LibmsiDatabase *db, const char *szTableName, L
 
     if (colinfo && n != maxcount)
     {
-        ERR("missing column in table %s\n", debugstr_a(szTableName));
+        g_critical("missing column in table %s\n", debugstr_a(szTableName));
         msi_free_colinfo( colinfo, maxcount );
         return LIBMSI_RESULT_FUNCTION_FAILED;
     }
@@ -727,7 +729,7 @@ unsigned msi_create_table( LibmsiDatabase *db, const char *name, column_info *co
     /* only add tables that don't exist already */
     if( table_view_exists(db, name ) )
     {
-        WARN("table %s exists\n", debugstr_a(name));
+        g_warning("table %s exists\n", debugstr_a(name));
         return LIBMSI_RESULT_BAD_QUERY_SYNTAX;
     }
 
@@ -910,7 +912,7 @@ static unsigned save_table( LibmsiDatabase *db, const LibmsiTable *t, unsigned b
 
             if (n != 2 && n != 3 && n != 4)
             {
-                ERR("oops - unknown column width %d\n", n);
+                g_critical("oops - unknown column width %d\n", n);
                 goto err;
             }
             if (t->colinfo[j].type & MSITYPE_STRING && n < m)
@@ -918,7 +920,7 @@ static unsigned save_table( LibmsiDatabase *db, const LibmsiTable *t, unsigned b
                 unsigned id = read_table_int( t->data, i, ofs_mem, LONG_STR_BYTES );
                 if (id > 1 << bytes_per_strref * 8)
                 {
-                    ERR("string id %u out of range\n", id);
+                    g_critical("string id %u out of range\n", id);
                     goto err;
                 }
             }
@@ -986,7 +988,7 @@ bool table_view_exists( LibmsiDatabase *db, const char *name )
     r = get_table( db, szTables, &table );
     if( r != LIBMSI_RESULT_SUCCESS )
     {
-        ERR("table %s not available\n", debugstr_a(szTables));
+        g_critical("table %s not available\n", debugstr_a(szTables));
         return false;
     }
 
@@ -1029,15 +1031,15 @@ static unsigned table_view_fetch_int( LibmsiView *view, unsigned row, unsigned c
 
     if( tv->columns[col-1].offset >= tv->row_size )
     {
-        ERR("Stuffed up %d >= %d\n", tv->columns[col-1].offset, tv->row_size );
-        ERR("%p %p\n", tv, tv->columns );
+        g_critical("Stuffed up %d >= %d\n", tv->columns[col-1].offset, tv->row_size );
+        g_critical("%p %p\n", tv, tv->columns );
         return LIBMSI_RESULT_FUNCTION_FAILED;
     }
 
     n = bytes_per_column( tv->db, &tv->columns[col - 1], LONG_STR_BYTES );
     if (n != 2 && n != 3 && n != 4)
     {
-        ERR("oops! what is %d bytes per column?\n", n );
+        g_critical("oops! what is %d bytes per column?\n", n );
         return LIBMSI_RESULT_FUNCTION_FAILED;
     }
 
@@ -1104,7 +1106,7 @@ static unsigned msi_stream_name( const LibmsiTableView *tv, unsigned row, char *
                     sprintf( number, fmt, ival^0x80000000 );
                     break;
                 default:
-                    ERR( "oops - unknown column width %d\n", n );
+                    g_critical( "oops - unknown column width %d\n", n );
                     r = LIBMSI_RESULT_FUNCTION_FAILED;
                     goto err;
                 }
@@ -1154,14 +1156,14 @@ static unsigned table_view_fetch_stream( LibmsiView *view, unsigned row, unsigne
     r = msi_stream_name( tv, row, &full_name );
     if ( r != LIBMSI_RESULT_SUCCESS )
     {
-        ERR("fetching stream, error = %d\n", r);
+        g_critical("fetching stream, error = %d\n", r);
         return r;
     }
 
     encname = encode_streamname( false, full_name );
     r = msi_get_raw_stream( tv->db, encname, stm );
     if( r )
-        ERR("fetching stream %s, error = %d\n",debugstr_a(full_name), r);
+        g_critical("fetching stream %s, error = %d\n",debugstr_a(full_name), r);
 
     if (*stm)
         g_object_set_data_full (G_OBJECT (*stm), "stname", full_name, g_free);
@@ -1186,8 +1188,8 @@ static unsigned table_view_set_int( LibmsiTableView *tv, unsigned row, unsigned
 
     if( tv->columns[col-1].offset >= tv->row_size )
     {
-        ERR("Stuffed up %d >= %d\n", tv->columns[col-1].offset, tv->row_size );
-        ERR("%p %p\n", tv, tv->columns );
+        g_critical("Stuffed up %d >= %d\n", tv->columns[col-1].offset, tv->row_size );
+        g_critical("%p %p\n", tv, tv->columns );
         return LIBMSI_RESULT_FUNCTION_FAILED;
     }
 
@@ -1197,7 +1199,7 @@ static unsigned table_view_set_int( LibmsiTableView *tv, unsigned row, unsigned
     n = bytes_per_column( tv->db, &tv->columns[col - 1], LONG_STR_BYTES );
     if ( n != 2 && n != 3 && n != 4 )
     {
-        ERR("oops! what is %d bytes per column?\n", n );
+        g_critical("oops! what is %d bytes per column?\n", n );
         return LIBMSI_RESULT_FUNCTION_FAILED;
     }
 
@@ -1225,7 +1227,7 @@ static unsigned _libmsi_add_stream( LibmsiDatabase *db, const char *name, GsfInp
         "INSERT INTO `_Streams`(`Name`, `Data`) VALUES (?, ?)";
     LibmsiQuery *query = NULL;
     LibmsiRecord *rec;
-    unsigned r;
+    unsigned r = LIBMSI_RESULT_SUCCESS;
 
     TRACE("%p %s %p\n", db, debugstr_a(name), data);
 
@@ -1285,7 +1287,7 @@ static unsigned get_table_value_from_record( LibmsiTableView *tv, LibmsiRecord *
         *pvalue = 0x8000 + libmsi_record_get_int( rec, iField );
         if ( *pvalue & 0xffff0000 )
         {
-            ERR("field %u value %d out of range\n", iField, *pvalue - 0x8000);
+            g_critical("field %u value %d out of range\n", iField, *pvalue - 0x8000);
             return LIBMSI_RESULT_FUNCTION_FAILED;
         }
     }
@@ -1573,7 +1575,7 @@ static int compare_record( LibmsiTableView *tv, unsigned row, LibmsiRecord *rec
         r = table_view_fetch_int( &tv->view, row, i + 1, &x );
         if (r != LIBMSI_RESULT_SUCCESS)
         {
-            WARN("table_view_fetch_int should not fail here %u\n", r);
+            g_warning("table_view_fetch_int should not fail here %u\n", r);
             return -1;
         }
         if (ivalue > x)
@@ -1724,8 +1726,8 @@ static unsigned table_view_find_matching_rows( LibmsiView *view, unsigned col,
 
         if( tv->columns[col-1].offset >= tv->row_size )
         {
-            ERR("Stuffed up %d >= %d\n", tv->columns[col-1].offset, tv->row_size );
-            ERR("%p %p\n", tv, tv->columns );
+            g_critical("Stuffed up %d >= %d\n", tv->columns[col-1].offset, tv->row_size );
+            g_critical("%p %p\n", tv, tv->columns );
             return LIBMSI_RESULT_FUNCTION_FAILED;
         }
 
@@ -1997,7 +1999,7 @@ unsigned table_view_create( LibmsiDatabase *db, const char *name, LibmsiView **v
     if( r != LIBMSI_RESULT_SUCCESS )
     {
         msi_free( tv );
-        WARN("table not found\n");
+        g_warning("table not found\n");
         return r;
     }
 
@@ -2034,14 +2036,14 @@ unsigned _libmsi_database_commit_tables( LibmsiDatabase *db, unsigned bytes_per_
         r = get_table( db, table->name, &t );
         if( r != LIBMSI_RESULT_SUCCESS )
         {
-            WARN("failed to load table %s (r=%08x)\n",
+            g_warning("failed to load table %s (r=%08x)\n",
                   debugstr_a(table->name), r);
             return r;
         }
         r = save_table( db, table, bytes_per_strref );
         if( r != LIBMSI_RESULT_SUCCESS )
         {
-            WARN("failed to save table %s (r=%08x)\n",
+            g_warning("failed to save table %s (r=%08x)\n",
                   debugstr_a(table->name), r);
             return r;
         }
@@ -2215,7 +2217,7 @@ static LibmsiRecord *msi_get_transform_record( const LibmsiTableView *tv, const
                 TRACE(" field %d [0x%08x]\n", i+1, val );
                 break;
             default:
-                ERR("oops - unknown column width %d\n", n);
+                g_critical("oops - unknown column width %d\n", n);
                 break;
             }
             ofs += n;
@@ -2314,7 +2316,7 @@ static unsigned msi_row_matches( LibmsiTableView *tv, unsigned row, const unsign
         r = table_view_fetch_int( &tv->view, row, i+1, &x );
         if ( r != LIBMSI_RESULT_SUCCESS )
         {
-            ERR("table_view_fetch_int shouldn't fail here\n");
+            g_critical("table_view_fetch_int shouldn't fail here\n");
             break;
         }
 
@@ -2444,7 +2446,7 @@ static unsigned msi_table_load_transform( LibmsiDatabase *db, GsfInfile *stg,
         /* check we didn't run of the end of the table */
         if (n + sz > rawsize)
         {
-            ERR("borked.\n");
+            g_critical("borked.\n");
             dump_table( st, (uint16_t *)rawdata, rawsize );
             break;
         }
@@ -2453,13 +2455,13 @@ static unsigned msi_table_load_transform( LibmsiDatabase *db, GsfInfile *stg,
         if (rec)
         {
             char table[32];
-            unsigned sz = 32;
             unsigned number = LIBMSI_NULL_INT;
             unsigned row = 0;
 
             if (!strcmp( name, szColumns ))
             {
-                _libmsi_record_get_string( rec, 1, table, &sz );
+                unsigned tablesz = 32;
+                _libmsi_record_get_string( rec, 1, table, &tablesz );
                 number = libmsi_record_get_int( rec, 2 );
 
                 /*
@@ -2480,7 +2482,7 @@ static unsigned msi_table_load_transform( LibmsiDatabase *db, GsfInfile *stg,
                 }
             }
 
-            if (TRACE_ON(msidb)) dump_record( rec );
+            if (TRACE_ON) dump_record( rec );
 
             r = msi_table_find_row( tv, rec, &row, NULL );
             if (r == LIBMSI_RESULT_SUCCESS)
@@ -2490,21 +2492,21 @@ static unsigned msi_table_load_transform( LibmsiDatabase *db, GsfInfile *stg,
                     TRACE("deleting row [%d]:\n", row);
                     r = table_view_delete_row( &tv->view, row );
                     if (r != LIBMSI_RESULT_SUCCESS)
-                        WARN("failed to delete row %u\n", r);
+                        g_warning("failed to delete row %u\n", r);
                 }
                 else if (mask & 1)
                 {
                     TRACE("modifying full row [%d]:\n", row);
                     r = table_view_set_row( &tv->view, row, rec, (1 << tv->num_cols) - 1 );
                     if (r != LIBMSI_RESULT_SUCCESS)
-                        WARN("failed to modify row %u\n", r);
+                        g_warning("failed to modify row %u\n", r);
                 }
                 else
                 {
                     TRACE("modifying masked row [%d]:\n", row);
                     r = table_view_set_row( &tv->view, row, rec, mask );
                     if (r != LIBMSI_RESULT_SUCCESS)
-                        WARN("failed to modify row %u\n", r);
+                        g_warning("failed to modify row %u\n", r);
                 }
             }
             else
@@ -2512,7 +2514,7 @@ static unsigned msi_table_load_transform( LibmsiDatabase *db, GsfInfile *stg,
                 TRACE("inserting row\n");
                 r = table_view_insert_row( &tv->view, rec, -1, false );
                 if (r != LIBMSI_RESULT_SUCCESS)
-                    WARN("failed to insert row %u\n", r);
+                    g_warning("failed to insert row %u\n", r);
             }
 
             if (number != LIBMSI_NULL_INT && !strcmp( name, szColumns ))
@@ -2568,7 +2570,7 @@ unsigned msi_table_apply_transform( LibmsiDatabase *db, GsfInfile *stg )
         if ( encname[0] != 0xe4 || encname[1] != 0xa1 || encname[2] != 0x80)
             continue;
 
-        decode_streamname( encname, name );
+        decode_streamname( (char*)encname, name );
         if ( !strcmp( name+3, szStringPool ) ||
              !strcmp( name+3, szStringData ) )
             continue;
